@@ -1,6 +1,7 @@
 use crate::{
     buffer::{CellBuffer, Contacts, Span},
     fragment,
+    fragment::Arc,
     fragment::Circle,
     Cell, Point, Settings,
 };
@@ -411,6 +412,7 @@ lazy_static! {
         })
     );
 
+
     /// The fragments for each of the circle
     /// Calculate the span and get the group fragments
     static ref FRAGMENTS_CIRCLE: Vec<(Vec<Contacts>,Circle)> = Vec::from_iter(
@@ -441,11 +443,6 @@ lazy_static! {
         })
     );
 
-
-    /// Simplified version of fragment arcs derived from CIRCLE_MAP
-    /// Algorithm:
-    /// 1. Locate the cells corresponding to the 4 quadrant boundary of the circle
-    ///
     /// top_left      top       top_right
     ///               p2
     ///          arc2  |    arc1
@@ -456,131 +453,157 @@ lazy_static! {
     ///               p4
     /// bottom_left  bottom   bottom_right
     ///
-    ///   p1 = center.x + radius, center.y
-    ///   p2 = center.x, center.y - radius
-    ///   p3 = center.x - radius, center.y
-    ///   p4 = center.x + radius, center.y + radius
-    ///
-    ///  right,top,left,bottom, top_left, top_right,bottom_left,bottom_right are cells dervied from
-    ///  bounds.
-    ///
-    ///  assert that snapping points to cell corresponds respectively:
-    ///     p1 -> right cell
-    ///     p2 -> top cell
-    ///     p3 -> left cell
-    ///     p4 -> bottom cell
-    ///
-    /// 2. Locate the span of each quadrants
-    ///    arc4 span is always center_cell, to bottom_right
-    ///    arc2 span is conditional
-    ///     if center cell lies on mid, the span coverage is inclusive of the center cell.
-    ///     otherwise if the center cell lies on the edge, then the cell coverage is exclusive of
-    ///     the center cell
-    ///
-    static ref FRAGMENTS_ARC: Vec<(Vec<Contacts>,fragment::Arc)> =Vec::from_iter(
-            CIRCLE_MAP.iter().skip(3).flat_map(|(art, center, radius, edge_case, offset_center_y)|{
-                let cb = CellBuffer::from(*art);
-                let mut spans = cb.group_adjacents();
-                assert_eq!(spans.len(), 1);
-                let span = spans.remove(0).localize();
+    /// (diameter, quarter arcs)
+    pub static ref QUARTER_ARC_SPAN: BTreeMap<i32, [(Arc,Span);4]> = BTreeMap::from_iter(
+        CIRCLE_MAP.iter().skip(3).map(|(art, center, radius, edge_case, offset_center_y)|{
+            let span = circle_art_to_span(art);
+            let bounds = span.cell_bounds().expect("must have bounds");
+            let top_left = bounds.top_left();
+            let bottom_right = bounds.bottom_right();
+            let top_right = bounds.top_right();
+            let bottom_left = bounds.bottom_left();
 
-                let (start_bound, end_bound) = span.bounds().expect("There should be bounds");
-
-                let center_cell = center.cell();
-
-                let right = Cell::new(end_bound.x, center_cell.y);
-                let top = Cell::new(center_cell.x, start_bound.y);
-                let left = Cell::new(start_bound.x, center_cell.y);
-                let bottom = Cell::new(center_cell.x, end_bound.y);
-
-                let top_left = Cell::new(left.x, top.y);
-                let top_right = Cell::new(right.x, top.y);
-                let bottom_left = Cell::new(left.x, bottom.y);
-                let bottom_right = Cell::new(right.x, bottom.y);
-                assert_eq!(top_left, start_bound);
-                assert_eq!(bottom_right, end_bound);
+            let p1 = Point::new(center.x + radius, center.y);
+            let p2 = Point::new(center.x, center.y - radius);
+            let p3 = Point::new(center.x - radius, center.y);
+            let p4 = Point::new(center.x, center.y + radius);
 
 
-                // include cx if the center lies on the horizontal midline
-                // include cy if the center lies on the veritcal midline
-                let cx_adjusted = if !center.is_edge_x(){ center_cell.x }else{ center_cell.x - 1 };
-                let cy_adjusted = if !center.is_edge_y(){ center_cell.y }else{ center_cell.y - 1 };
+            let center_cell = center.cell();
 
-                let arc1_bounds = Cell::rearrange_bound(Cell::new(center_cell.x, cy_adjusted), top_right);
-                let arc2_bounds = Cell::rearrange_bound(top_left, Cell::new( cx_adjusted, cy_adjusted));
-                let arc3_bounds = Cell::rearrange_bound(bottom_left, Cell::new(cx_adjusted, center_cell.y));
-                let arc4_bounds = Cell::rearrange_bound(center_cell, bottom_right);
+            // TODO: use the edge_case from the circle_art map
+            let cx_adjusted = if !center.is_edge_x(){ center_cell.x }else{ center_cell.x - 1 };
+            let cy_adjusted = if !center.is_edge_y(){ center_cell.y }else{ center_cell.y - 1 };
 
-                let arc1_span = span.extract(arc1_bounds.0, arc1_bounds.1);
-                let arc2_span = span.extract(arc2_bounds.0, arc2_bounds.1);
-                let arc3_span = span.extract(arc3_bounds.0, arc3_bounds.1);
-                let arc4_span = span.extract(arc4_bounds.0, arc4_bounds.1);
+            let span1_center = Cell::new(center_cell.x, cy_adjusted);
+            let span2_center = Cell::new(cx_adjusted, cy_adjusted);
+            let span3_center = Cell::new(cx_adjusted, center_cell.y);
+            let span4_center = center_cell;
 
-                let p1 = Point::new(center.x + radius, center.y);
-                let p2 = Point::new(center.x, center.y - radius);
-                let p3 = Point::new(center.x - radius, center.y);
-                let p4 = Point::new(center.x, center.y + radius);
+            let bounds1 = Cell::rearrange_bound(span1_center, top_right);
+            let bounds2 = Cell::rearrange_bound(top_left, span2_center);
+            let bounds3 = Cell::rearrange_bound(bottom_left, span3_center);
+            let bounds4 = Cell::rearrange_bound(span4_center, bottom_right);
 
-                let arc1_start  = arc1_bounds.0.localize_point(p1);
-                let arc1_end = arc1_bounds.0.localize_point(p2);
+            let span1 = span.extract(bounds1.0, bounds1.1).localize();
+            let span2 = span.extract(bounds2.0, bounds2.1).localize();
+            let span3 = span.extract(bounds3.0, bounds3.1).localize();
+            let span4 = span.extract(bounds4.0, bounds4.1).localize();
 
-                let arc2_start = arc2_bounds.0.localize_point(p2);
-                let arc2_end = arc2_bounds.0.localize_point(p3);
+            let arc1_start  = bounds1.0.localize_point(p1);
+            let arc1_end = bounds1.0.localize_point(p2);
 
-                let arc3_start = arc3_bounds.0.localize_point(p3);
-                let arc3_end = arc3_bounds.0.localize_point(p4);
+            let arc2_start = bounds2.0.localize_point(p2);
+            let arc2_end = bounds2.0.localize_point(p3);
 
-                let arc4_start = arc4_bounds.0.localize_point(p4);
-                let arc4_end = arc4_bounds.0.localize_point(p1);
+            let arc3_start = bounds3.0.localize_point(p3);
+            let arc3_end = bounds3.0.localize_point(p4);
 
-                let arc1  = fragment::Arc::new(arc1_start, arc1_end, *radius);
-                let arc2  = fragment::Arc::new(arc2_start, arc2_end, *radius);
-                let arc3  = fragment::Arc::new(arc3_start, arc3_end, *radius);
-                let arc4  = fragment::Arc::new(arc4_start, arc4_end, *radius);
+            let arc4_start = bounds4.0.localize_point(p4);
+            let arc4_end = bounds4.0.localize_point(p1);
 
-                //TODO: get the settings supplied by the user
-                let settings = &Settings::default();
+            let arc1 = Arc::new(arc1_start, arc1_end, *radius);
+            let arc2 = Arc::new(arc2_start, arc2_end, *radius);
+            let arc3 = Arc::new(arc3_start, arc3_end, *radius);
+            let arc4 = Arc::new(arc4_start, arc4_end, *radius);
 
-                vec![
-                    (arc1_span.get_contacts(settings), arc1),
-                    (arc2_span.get_contacts(settings), arc2),
-                    (arc3_span.get_contacts(settings), arc3),
-                    (arc4_span.get_contacts(settings), arc4),
-                ]
-            })
+            let diameter = (*radius * 2.0) as i32;
+            (diameter, [(arc1, span1), (arc2, span2), (arc3, span3), (arc4, span4)])
+        })
+    );
+
+    /*
+    pub static ref HALF_ARC_SPAN: BTreeMap<i32,[(Arc,Span);4]> = BTreeMap::from_iter(
+        QUARTER_ARC_SPAN.iter().map(|(diameter, [(arc1, span1), (arc2, span2), (arc3, span3), (arc4, span4)])|{
+            let radius = (diameter / 2) as f32;
+
+            let half12 = Arc::new(arc1.start, arc2.end, radius);
+            let span12 = span2.paste_at(span2.cell_bounds().unwrap().top_right(), span1);
+
+            let half23 = Arc::new(arc2.start, arc3.end, radius);
+            let span23 = span2.paste_at(span2.cell_bounds().unwrap().bottom_left(), span3);
+
+            let half34 = Arc::new(arc3.start, arc4.end, radius);
+            let span34 = span3.paste_at(span3.cell_bounds().unwrap().top_right(), span4);
+
+            let half41 = Arc::new(arc4.start, arc1.end, radius);
+            let span41 = span1.paste_at(span1.cell_bounds().unwrap().bottom_left(), span4);
+
+            (*diameter, [(half12, span12), (half23, span23), (half34, span34), (half41, span41)])
+        })
+    );
+    */
+
+    pub static ref ARC_SPAN: BTreeMap<Arc,Span> = BTreeMap::from_iter(
+            QUARTER_ARC_SPAN.iter()
+                .flat_map(|(_diameter, arcs)|arcs.clone())
     );
 
 }
 
 fn circle_art_to_group(art: &str, settings: &Settings) -> Vec<Contacts> {
-    let cell_buffer = CellBuffer::from(art);
-    let mut spans: Vec<Span> = cell_buffer.group_adjacents();
-    assert_eq!(spans.len(), 1);
-    let span1 = spans.remove(0);
+    let span1 = circle_art_to_span(art);
     span1.get_contacts(settings)
 }
 
-/// [X](Done) TODO: search only the subset of contacts that matches the circle.
-/// if it is a subset then the circle is matched and the non-matching ones are returned
-pub fn endorse_circle(search: &Vec<Contacts>) -> Option<(&Circle, Vec<usize>)> {
-    FRAGMENTS_CIRCLE
-        .iter()
-        .rev()
-        .find_map(|(contacts, circle)| {
-            let (matched, unmatched) = is_subset_of(contacts, search);
-            if matched {
-                Some((circle, unmatched))
-            } else {
-                None
-            }
-        })
+fn circle_art_to_span(art: &str) -> Span {
+    let cell_buffer = CellBuffer::from(art);
+    let mut spans = cell_buffer.group_adjacents();
+    assert_eq!(spans.len(), 1);
+    spans.remove(0).localize()
+}
+
+pub fn endorse_circle_span(search: &Span) -> Option<(&Circle, Span)> {
+    CIRCLES_SPAN.iter().rev().find_map(|(circle, span)| {
+        let search_localized = search.clone().localize();
+        let (matched, unmatched) = is_subset_of(span, &search_localized);
+        if matched {
+            let unmatched_cell_chars = search
+                .iter()
+                .enumerate()
+                .filter_map(|(i, cell_char)| {
+                    if unmatched.contains(&i) {
+                        Some(cell_char.clone())
+                    } else {
+                        None
+                    }
+                })
+                .collect::<Vec<_>>();
+            Some((circle, Span::from(unmatched_cell_chars)))
+        } else {
+            None
+        }
+    })
+}
+
+pub fn endorse_arc_span(search: &Span) -> Option<(&Arc, Span)> {
+    ARC_SPAN.iter().find_map(|(arc, span)| {
+        let search_localized = search.clone().localize();
+        let (matched, unmatched) = is_subset_of(span, &search_localized);
+        if matched {
+            let unmatched_cell_chars = search
+                .iter()
+                .enumerate()
+                .filter_map(|(i, cell_char)| {
+                    if unmatched.contains(&i) {
+                        Some(cell_char.clone())
+                    } else {
+                        None
+                    }
+                })
+                .collect::<Vec<_>>();
+            Some((arc, Span::from(unmatched_cell_chars)))
+        } else {
+            None
+        }
+    })
 }
 
 /// returns true if all the contacts in subset is in big_set
 /// This also returns the indices of big_set that are not found in the subset
-fn is_subset_of(
-    subset: &Vec<Contacts>,
-    big_set: &Vec<Contacts>,
+fn is_subset_of<T: PartialEq>(
+    subset: &[T],
+    big_set: &[T],
 ) -> (bool, Vec<usize>) {
     let mut unmatched = vec![];
     let mut matched = 0;
@@ -597,239 +620,5 @@ fn is_subset_of(
     (matched == subset.len(), unmatched)
 }
 
-/// searches from the largest arc first
-/// [x](solved) ISSUE: An arc can have multiple matches at different radius.
-/// searching from the largest or from the smallest will still result in 4 parts not equally
-/// proportional, due to 1 of the arc not matching on the same arc level since the
-/// arc parameters is determine only by the contacts, and have no clue about it's radius.
-/// Multiple arc contacts can be the same while not having the same arc radius.
-pub fn endorse_arc(
-    search: &Vec<Contacts>,
-) -> Option<(&fragment::Arc, Vec<usize>)> {
-    FRAGMENTS_ARC.iter().rev().find_map(|(contacts, arc)| {
-        let (matched, unmatched) = is_subset_of(contacts, search);
-        if matched {
-            Some((arc, unmatched))
-        } else {
-            None
-        }
-    })
-}
-
 #[cfg(test)]
-mod tests {
-    use super::*;
-
-    #[test]
-    fn access_circles() {
-        let len = DIAMETER_CIRCLE.len();
-        println!("len: {}", len);
-        assert_eq!(len, 22);
-        let frag_len = FRAGMENTS_ARC.len();
-        println!("frag len: {}", frag_len);
-        assert_eq!(frag_len, 76);
-    }
-
-    #[test]
-    fn test_circle1() {
-        let art = r#"
-                _.-'''''''-._
-              ,'             `.
-             /                 \
-            .                   .
-            |                   |
-            |                   |
-            |                   |
-             \                 /
-              `._           _.'
-                 '-.......-'
-            "#;
-        let cell_buffer = CellBuffer::from(art);
-        let mut spans: Vec<Span> = cell_buffer.group_adjacents();
-        assert_eq!(spans.len(), 1);
-        let span1 = spans.remove(0);
-        let groups = span1.get_contacts(&Settings::default());
-        for (i, group) in groups.iter().enumerate() {
-            println!("group{}\n{}", i, group);
-        }
-        assert_eq!(11, groups.len());
-    }
-
-    #[test]
-    fn test_arc9_top_right() {
-        let art = r#"
-            __
-              `.
-                \
-            "#;
-        let cell_buffer = CellBuffer::from(art);
-        let mut spans: Vec<Span> = cell_buffer.group_adjacents();
-        assert_eq!(spans.len(), 1);
-        let span1 = spans.remove(0);
-        let groups = span1.get_contacts(&Settings::default());
-        for (i, group) in groups.iter().enumerate() {
-            println!("group{}\n{}", i, group);
-        }
-        assert_eq!(2, groups.len());
-        let (arc, _) = endorse_arc(&groups).unwrap();
-        assert_eq!(arc.radius, 5.0);
-    }
-
-    #[test]
-    fn test_arc5_top_right() {
-        let art = r#"
-            -.
-              )
-            "#;
-        let cell_buffer = CellBuffer::from(art);
-        let mut spans: Vec<Span> = cell_buffer.group_adjacents();
-        assert_eq!(spans.len(), 1);
-        let span1 = spans.remove(0);
-        let groups = span1.get_contacts(&Settings::default());
-        for (i, group) in groups.iter().enumerate() {
-            println!("group{}\n{}", i, group);
-        }
-        let (arc, _) = endorse_arc(&groups).unwrap();
-        assert_eq!(arc.radius, 2.5);
-    }
-
-    #[test]
-    fn test_arc5_top_left() {
-        let art = r#"
-           .-
-          (
-            "#;
-        let cell_buffer = CellBuffer::from(art);
-        let mut spans: Vec<Span> = cell_buffer.group_adjacents();
-        assert_eq!(spans.len(), 1);
-        let span1 = spans.remove(0);
-        let groups = span1.get_contacts(&Settings::default());
-        for (i, group) in groups.iter().enumerate() {
-            println!("group{}\n{}", i, group);
-        }
-        let (arc, _) = endorse_arc(&groups).unwrap();
-        assert_eq!(arc.radius, 2.5);
-    }
-
-    #[test]
-    fn test_arc5_bottom_left() {
-        let art = r#"
-          (
-           `-
-            "#;
-        let cell_buffer = CellBuffer::from(art);
-        let mut spans: Vec<Span> = cell_buffer.group_adjacents();
-        assert_eq!(spans.len(), 1);
-        let span1 = spans.remove(0);
-        let groups = span1.get_contacts(&Settings::default());
-        for (i, group) in groups.iter().enumerate() {
-            println!("group{}\n{}", i, group);
-        }
-        let (arc, _) = endorse_arc(&groups).unwrap();
-        assert_eq!(arc.radius, 2.5);
-    }
-
-    #[test]
-    fn test_arc5_bottom_right() {
-        let art = r#"
-              )
-            -'
-            "#;
-        let cell_buffer = CellBuffer::from(art);
-        let mut spans: Vec<Span> = cell_buffer.group_adjacents();
-        assert_eq!(spans.len(), 1);
-        let span1 = spans.remove(0);
-        let groups = span1.get_contacts(&Settings::default());
-        for (i, group) in groups.iter().enumerate() {
-            println!("group{}\n{}", i, group);
-        }
-        let (arc, _) = endorse_arc(&groups).unwrap();
-        assert_eq!(arc.radius, 2.5);
-    }
-
-    #[test]
-    fn test_arc20_top_right() {
-        let art = r#"
-            ''''-._
-                   `.
-                     \
-                      .
-                      |
-                      |
-            "#;
-        let cell_buffer = CellBuffer::from(art);
-        let mut spans: Vec<Span> = cell_buffer.group_adjacents();
-        assert_eq!(spans.len(), 1);
-        let span1 = spans.remove(0);
-        let groups = span1.get_contacts(&Settings::default());
-        for (i, group) in groups.iter().enumerate() {
-            println!("group{}\n{}", i, group);
-        }
-        let (arc, _) = endorse_arc(&groups).unwrap();
-        assert_eq!(arc.radius, 10.5); //also matched the arc21 radius and since larger it will matched it instead of arc20
-    }
-
-    #[test]
-    fn test_arc20_top_left() {
-        let art = r#"
-                    _.-''''
-                  ,'
-                 /
-                .
-                |
-                |
-            "#;
-        let cell_buffer = CellBuffer::from(art);
-        let mut spans: Vec<Span> = cell_buffer.group_adjacents();
-        assert_eq!(spans.len(), 1);
-        let span1 = spans.remove(0);
-        let groups = span1.get_contacts(&Settings::default());
-        for (i, group) in groups.iter().enumerate() {
-            println!("group{}\n{}", i, group);
-        }
-        let (arc, _) = endorse_arc(&groups).unwrap();
-        assert_eq!(arc.radius, 10.5); //also matched the arc21 radius and since larger it will matched it instead of arc20
-    }
-
-    #[test]
-    fn test_arc20_bottom_left() {
-        let art = r#"
-                |
-                |
-                 \
-                  `._
-                     '-....
-            "#;
-        let cell_buffer = CellBuffer::from(art);
-        let mut spans: Vec<Span> = cell_buffer.group_adjacents();
-        assert_eq!(spans.len(), 1);
-        let span1 = spans.remove(0);
-        let groups = span1.get_contacts(&Settings::default());
-        for (i, group) in groups.iter().enumerate() {
-            println!("group{}\n{}", i, group);
-        }
-        let (arc, _) = endorse_arc(&groups).unwrap();
-        assert_eq!(arc.radius, 10.0);
-    }
-
-    #[test]
-    fn test_arc20_bottom_right() {
-        let art = r#"
-                          |
-                          |
-                         /
-                      _.'
-                ....-'
-            "#;
-        let cell_buffer = CellBuffer::from(art);
-        let mut spans: Vec<Span> = cell_buffer.group_adjacents();
-        assert_eq!(spans.len(), 1);
-        let span1 = spans.remove(0);
-        let groups = span1.get_contacts(&Settings::default());
-        for (i, group) in groups.iter().enumerate() {
-            println!("group{}\n{}", i, group);
-        }
-        let (arc, _) = endorse_arc(&groups).unwrap();
-        assert_eq!(arc.radius, 10.0);
-    }
-}
+mod test_circle_map;
